from .logging import Logging
from flask import request
import functools


def log_request(logger: Logging):
    """
        Decorates a flask route to log request and response
    """

    def decorator(func):

        @functools.wraps(func)
        def wrapper_log_request(*args, **kwargs):
            request_data = request.get_json(silent=True)

            logger.log_request(request.url, request.method, request_data)

            response_data = func(*args, **kwargs)

            logger.log_request(
                request.url,
                request.method,
                response_data if type(response_data) is not tuple else response_data[0],
                request_type='RESPONSE'
            )

            return response_data

        return wrapper_log_request

    return decorator
